@@ -10,6 +10,8 @@ def os_mount_points():
         'nfs4',
         'p9', # file system used in WSL 2 (Windows Subsystem for Linux)
         'btrfs',
+        'fuse', # https://github.com/andreafrancia/trash-cli/issues/250
+        'fuse.glusterfs', #https://github.com/andreafrancia/trash-cli/issues/255
     ]
 
     # Append fstypes of physical devices to list
